@@ -9,10 +9,11 @@ module ActiveRecord::Import::AbstractAdapter
     def insert_many( sql, values, _options = {}, *args ) # :nodoc:
       number_of_inserts = 1
 
-      base_sql, post_sql = if sql.is_a?( String )
-        [sql, '']
-      elsif sql.is_a?( Array )
-        [sql.shift, sql.join( ' ' )]
+      base_sql, post_sql = case sql
+                           when String
+                             [sql, '']
+                           when Array
+                             [sql.shift, sql.join( ' ' )]
       end
 
       sql2insert = base_sql + values.join( ',' ) + post_sql
@@ -47,7 +48,7 @@ module ActiveRecord::Import::AbstractAdapter
       post_sql_statements = []
 
       if supports_on_duplicate_key_update? && options[:on_duplicate_key_update]
-        post_sql_statements << sql_for_on_duplicate_key_update( table_name, options[:on_duplicate_key_update], options[:primary_key], options[:locking_column] )
+        post_sql_statements << sql_for_on_duplicate_key_update( table_name, options[:on_duplicate_key_update], options[:model], options[:primary_key], options[:locking_column] )
       elsif logger && options[:on_duplicate_key_update]
         logger.warn "Ignoring on_duplicate_key_update because it is not supported by the database."
       end
