@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require File.expand_path(File.dirname(__FILE__) + '/../test_helper')
-require File.expand_path(File.dirname(__FILE__) + '/../support/postgresql/import_examples')
+require File.expand_path("#{File.dirname(__FILE__)}/../test_helper")
+require File.expand_path("#{File.dirname(__FILE__)}/../support/postgresql/import_examples")
 
 should_support_postgresql_import_functionality
 
